==> openturns_0.12.2.orig.tar.gz: openturns-0.12.2/lib/test/t_ConfidenceInterval_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_ConfidenceInterval_std.cxx
 *  @brief The test file of class ConfidenceInterval
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-10-31 11:52:04 +0100 (ven 31 oct 2008) $
 *  Id:      $Id: t_ConfidenceInterval_std.cxx 995 2008-10-31 10:52:04Z dutka $
 */
#include <iostream>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include <cmath>
#include "ConfidenceInterval.hxx"


using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Stat;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  
  /** TEST NUMBER ZERO : DEFAULT CONSTRUCTOR AND STRING CONVERTER */
  std::cout << "test number zero : default constructor and string converter" << std::endl;
  
  /* Default constructor */
  NumericalScalar begin=1.0, end=36.92;
  ConfidenceInterval testInterval(begin, end);
  testInterval.setName("testInterval");
  
  /* String converter */
  std::cout << "testInterval = " << testInterval << std::endl;
  
  
  /** TEST NUMBER ONE : COPY CONSTRUCTOR AND STRING CONVERTER */
  std::cout << "test number one : copy constructor and string converter" << std::endl;
  
  /* Copy constructor */
  ConfidenceInterval testIntervalCopy(testInterval);
  
  /* String converter */
  std::cout << "testIntervalCopy = " << testIntervalCopy << std::endl;
  
  
  /** TEST NUMBER TWO : ELEMENTS ACCESSORS */
  std::cout << "test number two : elements accessors" << std::endl;
  
  NumericalScalar begin2=12.0, end2=92.3898754;
  ConfidenceInterval testIntervalCopy2(testInterval);
  testIntervalCopy2.setValues(begin2,end2);
  std::cout << "testIntervalCopy2 values = " << testIntervalCopy2.getFirst() << " ; " << testIntervalCopy2.getLast() << std::endl;
  
  /** TEST NUMBER THREE : EQUALITY TEST */
  std::cout << "testInterval == testIntervalCopy " << (testInterval == testIntervalCopy) << std::endl;
  std::cout << "testInterval == testIntervalCopy2 " << (testInterval == testIntervalCopy2) << std::endl;
  
	    
  return ExitCode::Success;
}

==> openturns_0.13.1.orig.tar.gz: openturns-0.13.1/lib/test/t_ConfidenceInterval_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_ConfidenceInterval_std.cxx
 *  @brief The test file of class ConfidenceInterval
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009) $
 *  Id:      $Id: t_ConfidenceInterval_std.cxx 1262 2009-05-28 12:47:53Z dutka $
 */
#include <iostream>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "OStream.hxx"
#include <cmath>
#include "ConfidenceInterval.hxx"


using namespace OT;
using namespace OT::Test;
using namespace OT::Base::Common;
using namespace OT::Base::Stat;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);
  
  /** TEST NUMBER ZERO : DEFAULT CONSTRUCTOR AND STRING CONVERTER */
  fullprint << "test number zero : default constructor and string converter" << std::endl;
  
  /* Default constructor */
  NumericalScalar begin=1.0, end=36.92;
  ConfidenceInterval testInterval(begin, end);
  testInterval.setName("testInterval");
  
  /* String converter */
  fullprint << "testInterval = " << testInterval << std::endl;
  
  
  /** TEST NUMBER ONE : COPY CONSTRUCTOR AND STRING CONVERTER */
  fullprint << "test number one : copy constructor and string converter" << std::endl;
  
  /* Copy constructor */
  ConfidenceInterval testIntervalCopy(testInterval);
  
  /* String converter */
  fullprint << "testIntervalCopy = " << testIntervalCopy << std::endl;
  
  
  /** TEST NUMBER TWO : ELEMENTS ACCESSORS */
  fullprint << "test number two : elements accessors" << std::endl;
  
  NumericalScalar begin2=12.0, end2=92.3898754;
  ConfidenceInterval testIntervalCopy2(testInterval);
  testIntervalCopy2.setValues(begin2,end2);
  fullprint << "testIntervalCopy2 values = " << testIntervalCopy2.getFirst() << " ; " << testIntervalCopy2.getLast() << std::endl;
  
  /** TEST NUMBER THREE : EQUALITY TEST */
  fullprint << "testInterval == testIntervalCopy " << (testInterval == testIntervalCopy) << std::endl;
  fullprint << "testInterval == testIntervalCopy2 " << (testInterval == testIntervalCopy2) << std::endl;
  
	    
  return ExitCode::Success;
}
